/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "vscode-uri", "./strings"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var vscode_uri_1 = require("vscode-uri");
    var strings_1 = require("./strings");
    var Slash = '/'.charCodeAt(0);
    function isAbsolutePath(path) {
        return path.charCodeAt(0) === Slash;
    }
    exports.isAbsolutePath = isAbsolutePath;
    function dirname(uri) {
        var lastIndexOfSlash = uri.lastIndexOf('/');
        return lastIndexOfSlash !== -1 ? uri.substr(0, lastIndexOfSlash) : '';
    }
    exports.dirname = dirname;
    function basename(uri) {
        var lastIndexOfSlash = uri.lastIndexOf('/');
        return uri.substr(lastIndexOfSlash + 1);
    }
    exports.basename = basename;
    function joinPath(uriString) {
        var paths = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            paths[_i - 1] = arguments[_i];
        }
        var uri = vscode_uri_1.URI.parse(uriString);
        var uriPath = uri.path;
        for (var _a = 0, paths_1 = paths; _a < paths_1.length; _a++) {
            var path = paths_1[_a];
            if (!strings_1.endsWith(uriPath, '/') && !strings_1.startsWith(path, '/')) {
                uriPath += '/';
            }
            uriPath += path;
        }
        return uri.with({ path: uriPath }).toString();
    }
    exports.joinPath = joinPath;
    function resolvePath(uriString, path) {
        if (isAbsolutePath(path)) {
            var uri = vscode_uri_1.URI.parse(uriString);
            return uri.with({ path: path }).toString();
        }
        return joinPath(uriString, path);
    }
    exports.resolvePath = resolvePath;
});
